/**
* Interface for writers.
*/
module mde.mergetag.iface.IWriter;

import mde.mergetag.DataSet;


/** Interface for all mergetag writers (MTTWriter etc.).
*/
interface IWriter {
    DataSet dataset ();                 /// Get the DataSet
    void dataset (DataSet);             /// Set the DataSet
    
    void write ();                      /// Commence writing
}

/**
* Enumeration for specifying the writing method ("Params" section shows possible values).
*
* Params:
* FromExtension = Determine writing format from file name extension (must be one of .mtb or .mtt).
* Binary = Use binary mode (adds extension .mtb without checking for an existing extension).
* Text = Use text mode (adds extension .mtt without checking for an existing extension).
* Both = Write simultaneously in binary and text modes (with appropriate extensions added to each
* file name.
*/
enum WriterMethod : byte {
    FromExtension = -1,
    Binary = 1,
    Text = 2,
    Both = 3
}
